import{d as g,eB as y,o as _,u as e,b as p,c as b,eu as w,f as a,w as o,bf as I,aq as l,bF as x,e as h,eE as k}from"./outputWidgets.f017b1ba.js";import{I as c}from"./router.bd5e0bcd.js";import"./index.2d300106.js";import{O as B}from"./organization.b2f4c184.js";import{a as C}from"./asyncComputed.9ec0ae7d.js";import{A as v}from"./Title.4002b692.js";import{A}from"./index.5cbbe314.js";import{A as D}from"./index.0deb07e4.js";import{C as N}from"./Card.9bd70da8.js";import"./Form.c4ae4d63.js";import"./hasIn.a2b4c2f9.js";import"./popupNotifcation.d47f45e7.js";import"./index.cf4c23b9.js";import"./record.e2bcfa5f.js";import"./pubsub.4d72db7b.js";import"./Base.bb2b5283.js";import"./Typography.5dfc411f.js";import"./TabPane.3d7693e6.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="06a9d810-cc34-4728-87b1-d2a0d0218b14",t._sentryDebugIdIdentifier="sentry-dbid-06a9d810-cc34-4728-87b1-d2a0d0218b14")}catch{}})();const z={key:1},M={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},Z=g({__name:"Billing",setup(t){const r=y().params.organizationId,{loading:m,result:u}=C(()=>B.get(r));_(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const f=()=>c.showNewMessage("I want to upgrade my plan");return(E,V)=>e(m)?(p(),b(e(I),{key:0})):(p(),w("div",z,[a(e(A),{justify:"space-between",align:"center"},{default:o(()=>[a(e(v),{level:3},{default:o(()=>[l("Current plan")]),_:1})]),_:1}),a(e(D),{style:{"margin-top":"0"}}),a(e(N),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(x),{onClick:f},{default:o(()=>[l("Upgrade")]),_:1})]),default:o(()=>{var s,i,d;return[h("div",M,k((d=(i=(s=e(u))==null?void 0:s.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{Z as default};
//# sourceMappingURL=Billing.8f1cca6b.js.map
