import{C as r,E as t,K as i,a as f,M as b,c,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.a7b5bb1d.js";import"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="d6ea31dd-96bb-46fd-ae0d-d0a0c996f3b4",e._sentryDebugIdIdentifier="sentry-dbid-d6ea31dd-96bb-46fd-ae0d-d0a0c996f3b4")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,f as KeyMod,b as MarkerSeverity,c as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.4523f118.js.map
