import{_ as f}from"./Navbar.vue_vue_type_script_setup_true_lang.c7af449a.js";import{g as p}from"./api.646486da.js";import{a as _}from"./asyncComputed.9ec0ae7d.js";import{W as y}from"./WidgetsFrame.ba21a3b2.js";import{d as b,eB as g,b as n,eu as h,e as a,u as t,c as d,w,ew as l,eE as u,v}from"./outputWidgets.f017b1ba.js";import"./index.7f38f098.js";import"./pubsub.4d72db7b.js";import"./index.0750564d.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Base.bb2b5283.js";import"./Typography.5dfc411f.js";import"./Text.01ac3fdf.js";import"./runnerData.69ad746c.js";import"./url.42b30a4e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new B().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="66ea5819-f524-4cb9-8bf0-8849eb9de050",o._sentryDebugIdIdentifier="sentry-dbid-66ea5819-f524-4cb9-8bf0-8849eb9de050")}catch{}})();const k={class:"error"},I={class:"inner-content"},x=b({__name:"Error",setup(o){const r=g(),{result:e}=_(p),c=()=>{const{status:s}=r.params;switch(s){case"404":return{status:s,message:"Page not found."};case"403":return{status:s,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(s,C)=>(n(),h("div",null,[a("div",k,[t(e)?(n(),d(y,{key:0,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh"}},{default:w(()=>{var i,m;return[t(e)?(n(),d(f,{key:0,"brand-name":((i=t(e))==null?void 0:i.brandName)||((m=t(e))==null?void 0:m.name),"logo-url":t(e).logoUrl},null,8,["brand-name","logo-url"])):l("",!0),a("div",I,[a("h1",null,u(c().status),1),a("p",null,u(c().message),1)])]}),_:1},8,["main-color","theme","font-family"])):l("",!0)])]))}});const B=v(x,[["__scopeId","data-v-befb94cf"]]);export{B as default};
//# sourceMappingURL=Error.4cb47f30.js.map
