import{r as a,w as r}from"./runnerData.69ad746c.js";import"./outputWidgets.f017b1ba.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="95bc7b38-1d42-476b-bd54-4ed67277a4fb",t._sentryDebugIdIdentifier="sentry-dbid-95bc7b38-1d42-476b-bd54-4ed67277a4fb")}catch{}})();async function f(t){const e=await fetch(`/_pages/${t}`);if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:n}=await e.json();return n?a(n):null}async function u(){const t=await fetch("/_workspace");if(t.status!=200)return r({});const e=await t.json();return r(e)}export{f,u as g};
//# sourceMappingURL=api.646486da.js.map
