import{eV as t,eW as r}from"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="95230699-87b0-45d9-b9ce-b472e375ca43",e._sentryDebugIdIdentifier="sentry-dbid-95230699-87b0-45d9-b9ce-b472e375ca43")}catch{}})();function s(e,n){return t(1,arguments),r(e,Date.now(),n)}export{s as f};
//# sourceMappingURL=index.92e1480a.js.map
