import{C as n,A as o}from"./CollapsePanel.a2068d5c.js";import{T as t,A as a}from"./Timeline.f0acaa40.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="1a2f4107-a55f-44a8-a4e4-0c0309516b5b",e._sentryDebugIdIdentifier="sentry-dbid-1a2f4107-a55f-44a8-a4e4-0c0309516b5b")}catch{}})();n.Panel=o;n.install=function(e){return e.component(n.name,n),e.component(o.name,o),e};t.Item=a;t.install=function(e){return e.component(t.name,t),e.component(a.name,a),e};
//# sourceMappingURL=index.97a56b04.js.map
