import{e7 as b,ab as c,U as s,f as p,O as d}from"./outputWidgets.f017b1ba.js";import{B as y,b as u}from"./Base.bb2b5283.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="18f8d21b-10b6-412c-ab36-f02857fc464e",e._sentryDebugIdIdentifier="sentry-dbid-18f8d21b-10b6-412c-ab36-f02857fc464e")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,o){var n={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(n[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(n[t[r]]=e[t[r]]);return n};const m=b(1,2,3,4,5),_=()=>s(s({},d(u(),["component","strong"])),{level:Number}),l=(e,o)=>{let{slots:n,attrs:t}=o;const{level:r=1}=e,f=g(e,["level"]);let a;m.includes(r)?a=`h${r}`:(c(),a="h1");const i=s(s(s({},f),{component:a}),t);return p(y,i,n)};l.displayName="ATypographyTitle";l.inheritAttrs=!1;l.props=_();const w=l;export{w as A};
//# sourceMappingURL=Title.4002b692.js.map
