import{F as t}from"./Form.c4ae4d63.js";import{b1 as d,cm as n}from"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="683b0014-7749-4d09-b04c-e78cfcd6d6fa",e._sentryDebugIdIdentifier="sentry-dbid-683b0014-7749-4d09-b04c-e78cfcd6d6fa")}catch{}})();t.useInjectFormItemContext=d;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.b2067256.js.map
