.empty-hint[data-v-1acf9439]{position:absolute;top:0;left:0;width:100%;height:100%;pointer-events:none}.empty-hint .drag-hint[data-v-1acf9439]{top:75%;left:50%;width:100px;transform:translate(-50%)}.empty-hint .drag-hint .arrow[data-v-1acf9439]{animation:left-arrow-1acf9439 1s infinite}@keyframes left-arrow-1acf9439{0%{transform:translateY(-2px)}50%{transform:translateY(2px)}to{transform:translateY(-2px)}}.empty-hint .drop-hint[data-v-1acf9439]{top:50%;left:50%;transform:translate(-50%,-50%)}.empty-hint .drop-hint .arrow[data-v-1acf9439]{animation:down-arrow-1acf9439 1s infinite}@keyframes down-arrow-1acf9439{0%{transform:translateY(-5px)}50%{transform:translateY(5px)}to{transform:translateY(-5px)}}.empty-hint .stages-hint[data-v-1acf9439]{top:50%;left:50%;transform:translate(-50%,-50%);display:grid;gap:90px;grid-template-columns:repeat(3,1fr);position:absolute;color:#a0a0a0;font-size:20px;font-weight:500;text-align:center}.empty-hint .stages-hint .stage-hint[data-v-1acf9439]{display:flex;flex-direction:column;gap:10px}.empty-hint .stages-hint .stage-hint .header[data-v-1acf9439]{display:flex;align-items:center;justify-content:center;gap:10px}.empty-hint .stages-hint .stage-hint .header .title[data-v-1acf9439]{font-size:22px;font-weight:700}.empty-hint .stages-hint .stage-hint .description[data-v-1acf9439]{font-size:18px;font-weight:400}.empty-hint .drag-hint[data-v-1acf9439],.empty-hint .drop-hint[data-v-1acf9439]{position:absolute;color:#a0a0a0;font-size:20px;font-weight:500;text-align:center;display:flex;flex-direction:column;align-items:center;gap:16px}.empty-hint .drag-hint .title[data-v-1acf9439],.empty-hint .drop-hint .title[data-v-1acf9439]{font-size:20px;font-weight:500}.empty-hint .drag-hint .arrow[data-v-1acf9439],.empty-hint .drop-hint .arrow[data-v-1acf9439]{width:40px;height:40px;color:#a0a0a0}.stage-card[data-v-02a846e2]{outline:none;transition:transform 0 ease-in-out;cursor:pointer;position:absolute;user-select:none;top:0;left:0;pointer-events:initial;max-width:300px}.stage-card[data-v-02a846e2] .ant-card-body{padding:10px 15px}.stage-card.editing[data-v-02a846e2]{z-index:1;min-width:300px}.stage-card.selected .card[data-v-02a846e2]{border:1px solid var(--c09374dc)}.ant-form-item[data-v-02a846e2]{margin-bottom:0}.title-input[data-v-02a846e2]{border-bottom:1px solid #d9d9d9;border-radius:0;margin-right:12px}.transition-card[data-v-aaf3520b]{outline:none;display:flex;gap:5px;cursor:pointer;align-items:center;padding:6px;margin:4px;border-radius:2px;width:fit-content;position:absolute;user-select:none;top:0;left:0;pointer-events:initial;font-size:15px}.transition-card.selected[data-v-aaf3520b]{border-color:#000}.transition-card .editing .selector[data-v-aaf3520b]{min-width:200px}.selection-menu[data-v-d4bbc465]{position:absolute;user-select:none;top:0;left:0;pointer-events:initial;border-radius:12px;z-index:2}.menu-item[data-v-d4bbc465]{display:flex;justify-content:space-between;align-items:center;height:100%;gap:20px}.canvas-container[data-v-1286f44d]{flex-grow:1;flex-basis:0;position:relative;overflow:hidden;outline:none}.canvas-container[data-v-1286f44d]:focus{border:4px solid #ebebeb}.canvas-container .workflow-canvas[data-v-1286f44d]{position:absolute;top:0;left:0;width:100%;height:100%;user-select:none;background-color:#eaeaea}.canvas-container .items-container[data-v-1286f44d]{position:absolute;top:0px;left:0px;width:100%;height:100%;pointer-events:none}html,body{overscroll-behavior-x:none}.workflow-editor[data-v-db97b681]{position:relative;display:flex;flex-grow:1;height:100%;width:100%}.workflow-editor .workflow-toolbar[data-v-db97b681]{display:flex;position:absolute;left:50%;bottom:2%;flex-direction:row;background-color:#fff;align-items:center;gap:18px;padding:5px 10px;box-shadow:0 0 5px #0003;transform:translate(-50%);border-radius:5px}.workflow-editor .workflow-toolbar .toolbar-item[data-v-db97b681]{cursor:grab}.workflow-editor .workflow-toolbar .toolbar-item[data-v-db97b681]:hover{box-shadow:0 0 5px #0003;transform:rotate(-5deg)}
