.twin-container[data-v-795220e4]{display:flex;align-items:center;gap:20px}.right-arrow[data-v-795220e4]{width:50px}.using-container[data-v-795220e4]{display:flex;gap:40px}.fullwidth-input[data-v-795220e4]{width:100%}:root{--main-font-family: DM Sans, sans-serif}:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel{background-color:#fff;padding:10px}.table-data{padding:30px 0}.borderless-input[data-v-de962a93]{border:0;font-size:20px;margin:0;padding:0;font-weight:600;border-bottom:1px solid #f0f0f0;border-radius:0}
