import{B as n,R as t}from"./Badge.3a256db2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="6d4bd411-0ed9-4d37-87a1-82ed66860aee",e._sentryDebugIdIdentifier="sentry-dbid-6d4bd411-0ed9-4d37-87a1-82ed66860aee")}catch{}})();n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.23e2179b.js.map
