import{f as s,eH as p,d as b,b as y,c as m,w as r,u as i,aq as o,eE as c,m as g,bF as v,cz as _}from"./outputWidgets.f017b1ba.js";import{T as f}from"./Typography.5dfc411f.js";import{A as P}from"./index.5cbbe314.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="38ae9cbb-5c6c-4307-a3e5-fe0fc2414044",a._sentryDebugIdIdentifier="sentry-dbid-38ae9cbb-5c6c-4307-a3e5-fe0fc2414044")}catch{}})();var w={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm144.1 454.9L437.7 677.8a8.02 8.02 0 01-12.7-6.5V353.7a8 8 0 0112.7-6.5L656.1 506a7.9 7.9 0 010 12.9z"}}]},name:"play-circle",theme:"filled"};const h=w;function u(a){for(var t=1;t<arguments.length;t++){var e=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(e);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(e).filter(function(l){return Object.getOwnPropertyDescriptor(e,l).enumerable}))),n.forEach(function(l){C(a,l,e[l])})}return a}function C(a,t,e){return t in a?Object.defineProperty(a,t,{value:e,enumerable:!0,configurable:!0,writable:!0}):a[t]=e,a}var d=function(t,e){var n=u({},t,e.attrs);return s(p,u({},n,{icon:h}),null)};d.displayName="PlayCircleFilled";d.inheritAttrs=!1;const O=d,I=b({__name:"RunButton",props:{loading:{type:Boolean},disabled:{}},emits:["click","save"],setup(a,{emit:t}){return(e,n)=>(y(),m(i(_),{visible:e.disabled?void 0:!1,placement:"bottom"},{content:r(()=>[s(i(P),{vertical:"",gap:"small"},{default:r(()=>[s(i(f),{style:{"font-size":"16px"}},{default:r(()=>{var l;return[o(c((l=e.disabled)==null?void 0:l.title),1)]}),_:1}),s(i(f),null,{default:r(()=>{var l;return[o(c((l=e.disabled)==null?void 0:l.message),1)]}),_:1})]),_:1})]),default:r(()=>[s(i(v),{style:{width:"100%"},loading:e.loading,icon:g(i(O)),disabled:!!e.disabled,size:"large",type:"primary",onClick:n[0]||(n[0]=l=>t("click"))},{default:r(()=>[o(" Run ")]),_:1},8,["loading","icon","disabled"])]),_:1},8,["visible"]))}});export{I as _};
//# sourceMappingURL=RunButton.vue_vue_type_script_setup_true_lang.5d71c031.js.map
