import{f as o,eH as u,eN as f}from"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3a561281-9515-4ee9-aa0f-267649a82467",e._sentryDebugIdIdentifier="sentry-dbid-3a561281-9515-4ee9-aa0f-267649a82467")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(a){return Object.getOwnPropertyDescriptor(r,a).enumerable}))),n.forEach(function(a){c(e,a,r[a])})}return e}function c(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var i=function(t,r){var n=l({},t,r.attrs);return o(u,l({},n,{icon:f}),null)};i.displayName="CloseCircleOutlined";i.inheritAttrs=!1;const d=i;export{d as C};
//# sourceMappingURL=CloseCircleOutlined.03002791.js.map
