import{cx as r}from"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="7bfdaa59-0674-4adf-a07a-14c3baf6cdde",e._sentryDebugIdIdentifier="sentry-dbid-7bfdaa59-0674-4adf-a07a-14c3baf6cdde")}catch{}})();const f=(e,d,a)=>{r.error({message:e,description:d,onClick:a})};export{f as p};
//# sourceMappingURL=popupNotifcation.d47f45e7.js.map
