import{d as p,H as l,b as n,eu as o,e as a,aC as r,eC as d,ey as _,eE as i,ew as u,v as f}from"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="fc3158e9-5b64-40db-b9e0-a31d63069d17",e._sentryDebugIdIdentifier="sentry-dbid-fc3158e9-5b64-40db-b9e0-a31d63069d17")}catch{}})();const b={key:0,class:"p-steps p-component"},m={class:"p-steps-list"},y={class:"p-menuitem-link"},g={class:"p-steps-number"},I=p({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const s=e,c=l(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(h,v)=>e.stepsInfo?(n(),o("nav",b,[a("ol",m,[(n(!0),o(r,null,d(c.value,(k,t)=>(n(),o("li",{key:t,class:_(["p-steps-item",{"p-highlight":t+1===e.stepsInfo.current}])},[a("span",y,[a("span",g,i(t+1),1)])],2))),128))])])):u("",!0)}});const C=f(I,[["__scopeId","data-v-c916ecf3"]]);export{C as S};
//# sourceMappingURL=Steps.ce2711d2.js.map
