import{d as v,eA as h,H as k,b as t,eu as u,u as e,c as s,ew as w,e as C,w as n,ev as x,bf as I,aq as f,aC as D,eC as N,f as c,eE as T,v as B}from"./outputWidgets.f017b1ba.js";import{g as F}from"./api.646486da.js";import{a as H}from"./asyncComputed.9ec0ae7d.js";import{P as V}from"./PlayerNavbar.b323f789.js";import{F as z}from"./PhArrowSquareOut.vue.962eba4e.js";import"./index.b5f796df.js";import"./index.dc236740.js";import{A as _}from"./index.5cbbe314.js";import{T as y}from"./Typography.5dfc411f.js";import{C as A}from"./Card.9bd70da8.js";import"./runnerData.69ad746c.js";import"./url.42b30a4e.js";import"./index.7f38f098.js";import"./pubsub.4d72db7b.js";import"./repository.875b9f0a.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Base.bb2b5283.js";import"./Link.d1ea88f0.js";import"./Paragraph.3ffb559e.js";import"./Text.01ac3fdf.js";import"./Title.4002b692.js";import"./TabPane.3d7693e6.js";import"./hasIn.a2b4c2f9.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[i]="65e9b88e-0dc0-47ab-a78a-b2601e46aede",a._sentryDebugIdIdentifier="sentry-dbid-65e9b88e-0dc0-47ab-a78a-b2601e46aede")}catch{}})();const E={class:"page"},S=v({__name:"Home",setup(a){const i=h(),{result:r,loading:g}=H(F),m=k(()=>{var o,p;return(p=(o=r.value)==null?void 0:o.sidebar.filter(d=>d.visible))!=null?p:[]}),b=o=>{i.push({path:`/${o}`})};return(o,p)=>{var d;return t(),u("div",E,[e(r)?(t(),s(V,{key:0,"runner-data":e(r),"hide-sidebar":""},null,8,["runner-data"])):w("",!0),C("div",{class:"container",style:x({backgroundColor:(d=e(r))==null?void 0:d.theme})},[e(g)?(t(),s(e(I),{key:0})):m.value.length===0?(t(),s(e(y),{key:1,type:"secondary",style:{"font-size":"18px"}},{default:n(()=>[f(" There are no public forms available ")]),_:1})):(t(),s(e(_),{key:2,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:n(()=>[(t(!0),u(D,null,N(m.value,l=>(t(),s(e(A),{key:l.id,class:"form-card",onClick:P=>b(l.path)},{default:n(()=>[c(e(_),{gap:"large",align:"center",justify:"space-between"},{default:n(()=>[c(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:n(()=>[f(T(l.name),1)]),_:2},1024),c(e(z),{color:"#000",width:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}))],4)])}}});const ie=B(S,[["__scopeId","data-v-d7035593"]]);export{ie as default};
//# sourceMappingURL=Home.f862b5d8.js.map
