import{ab as f,U as t,O as d,f as p}from"./outputWidgets.f017b1ba.js";import{B as l,b}from"./Base.bb2b5283.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5aa364de-eb12-471a-9587-fd89b12f8ad6",e._sentryDebugIdIdentifier="sentry-dbid-5aa364de-eb12-471a-9587-fd89b12f8ad6")}catch{}})();const c=()=>t(t({},d(b(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),a=(e,s)=>{let{slots:o,attrs:r}=s;const{ellipsis:n}=e;f();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?d(n,["expandable","rows"]):n,component:"span"}),r);return p(l,i,o)};a.displayName="ATypographyText";a.inheritAttrs=!1;a.props=c();const g=a;export{g as A};
//# sourceMappingURL=Text.01ac3fdf.js.map
