import{K as n,L as p}from"./repository.469a5d35.js";import{E as s}from"./repository.875b9f0a.js";import{d as a,b as m,c,u as i}from"./outputWidgets.f017b1ba.js";import{l as d}from"./index.7f38f098.js";import"./asyncComputed.9ec0ae7d.js";import"./workspaces.aaea5068.js";import"./runnerData.69ad746c.js";import"./url.42b30a4e.js";import"./record.e2bcfa5f.js";import"./pubsub.4d72db7b.js";import"./scripts.d8d6bdcc.js";import"./envVars.952414d1.js";import"./api.1f698687.js";import"./index.cf4c23b9.js";import"./PhScroll.vue.80bb185b.js";import"./PhWebhooksLogo.vue.bee1b0d9.js";import"./index.5cbbe314.js";import"./ant-design.f8dd6064.js";import"./index.11845c93.js";import"./Modal.334f8812.js";import"./Text.01ac3fdf.js";import"./Base.bb2b5283.js";import"./Typography.5dfc411f.js";import"./index.b5f796df.js";import"./Link.d1ea88f0.js";import"./Paragraph.3ffb559e.js";import"./Title.4002b692.js";import"./index.b5d890a4.js";import"./index.92e1480a.js";import"./index.97a56b04.js";import"./CollapsePanel.a2068d5c.js";import"./Timeline.f0acaa40.js";import"./index.0deb07e4.js";import"./index.76f119cc.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.4a8c0ef7.js";import"./Card.9bd70da8.js";import"./TabPane.3d7693e6.js";import"./hasIn.a2b4c2f9.js";import"./vuedraggable.umd.c790090d.js";import"./index.b2067256.js";import"./Form.c4ae4d63.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="5c7e1c4c-ccdf-4696-a89d-67057ddf4789",t._sentryDebugIdIdentifier="sentry-dbid-5c7e1c4c-ccdf-4696-a89d-67057ddf4789")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const io=a({__name:"WorkflowKanban",setup(t){const o=new s,r=new f,e=new p("kanban");return(u,y)=>(m(),c(n,{"kanban-repository":i(o),storage:i(e),"stage-run-repository":i(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{io as default};
//# sourceMappingURL=WorkflowKanban.1bb21f13.js.map
