import{U as s,f as p,O as f}from"./outputWidgets.f017b1ba.js";import{B as d,b as i}from"./Base.bb2b5283.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="6a9a64f2-288e-4b67-aaff-5a6e3bf36460",a._sentryDebugIdIdentifier="sentry-dbid-6a9a64f2-288e-4b67-aaff-5a6e3bf36460")}catch{}})();const b=()=>f(i(),["component"]),r=(a,e)=>{let{slots:t,attrs:o}=e;const n=s(s(s({},a),{component:"div"}),o);return p(d,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=b();const c=r;export{c as A};
//# sourceMappingURL=Paragraph.3ffb559e.js.map
