import{g as d}from"./api.646486da.js";import{P as m}from"./Passwordless.e85302fa.js";import{a as p}from"./asyncComputed.9ec0ae7d.js";import{W as u}from"./WidgetsFrame.ba21a3b2.js";import{d as f,eA as l,eB as _,b as i,eu as y,e as g,u as s,c as h,w,ew as b,f as v,v as k}from"./outputWidgets.f017b1ba.js";import"./runnerData.69ad746c.js";import"./url.42b30a4e.js";import"./index.7f38f098.js";import"./pubsub.4d72db7b.js";import"./index.4a35214d.js";import"./PhArrowClockwise.vue.2fdd521a.js";import"./CircularLoading.f397eb8b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2d8224a9-e6f6-4225-967c-315150cce72f",e._sentryDebugIdIdentifier="sentry-dbid-2d8224a9-e6f6-4225-967c-315150cce72f")}catch{}})();const I={class:"login"},x=f({__name:"Login",setup(e){const t=l(),r=_(),{result:o}=p(d),c=()=>{const{redirect:a,...n}=r.query;if(a){t.push({path:a,query:n,params:r.params});return}t.push({name:"playerKanban",query:n})};return(a,n)=>(i(),y("div",null,[g("div",I,[s(o)?(i(),h(u,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:w(()=>[v(m,{onDone:c})]),_:1},8,["main-color","theme","font-family"])):b("",!0)])]))}});const A=k(x,[["__scopeId","data-v-33714d9d"]]);export{A as default};
//# sourceMappingURL=Login.2e303312.js.map
