import{B as s}from"./Base.bb2b5283.js";import{A as o}from"./Link.d1ea88f0.js";import{A as r}from"./Paragraph.3ffb559e.js";import{A as a}from"./Text.01ac3fdf.js";import{A as i}from"./Title.4002b692.js";import{T as e}from"./Typography.5dfc411f.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="68637528-8d5e-4698-9fd4-e390285723ff",n._sentryDebugIdIdentifier="sentry-dbid-68637528-8d5e-4698-9fd4-e390285723ff")}catch{}})();e.Text=a;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.b5f796df.js.map
