import{v as a,a as r,b as i,c as d,j as c,T as p,k as _,P as u,C as f,M as l,s as g,l as s,m as b,n as m,p as y,q as v}from"./outputWidgets.f017b1ba.js";import{s as w,a as o}from"./index.7f38f098.js";import"./pubsub.4d72db7b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="954df789-2a0d-4d70-abb1-749dd99ea508",e._sentryDebugIdIdentifier="sentry-dbid-954df789-2a0d-4d70-abb1-749dd99ea508")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),d(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=a(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=c({render:()=>b(k)});p.init(),_(e,o),x.init(),e.use(o),e.use(u),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.1fddc3f5.js.map
