import{l as a}from"./index.7f38f098.js";import"./outputWidgets.f017b1ba.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="e9489a16-8279-436c-968c-2b99cd7698e4",t._sentryDebugIdIdentifier="sentry-dbid-e9489a16-8279-436c-968c-2b99cd7698e4")}catch{}})();class r{constructor(e=a){this.fetch=e}async getData(e){return(await this.fetch("/_editor/api/kanban",{method:"POST",body:JSON.stringify(e),headers:{"Content-Type":"application/json"}})).json()}async getLogs(e){return(await this.fetch(`/_editor/api/kanban/logs/${e}`)).json()}async startJob(e){await this.fetch(`/_editor/api/kanban/jobs/${e}/start`,{method:"POST"})}}class i{constructor(e,s=a){this.authProvider=e,this.fetch=s}get headers(){return{"Content-Type":"application/json",...this.authProvider.authHeaders()}}async getData(e){return(await this.fetch("/_kanban/",{method:"POST",body:JSON.stringify(e),headers:this.headers})).json()}async getLogs(e){return(await this.fetch(`/_kanban/logs/${e}`,{headers:this.headers})).json()}async startJob(e){await this.fetch(`/_kanban/jobs/${e}/start`,{method:"POST",headers:this.headers})}}export{r as E,i as P};
//# sourceMappingURL=repository.875b9f0a.js.map
