import{d as m,b as n,eu as _,ew as h,e as C,eE as i,v as N,eA as A,a as B,u as e,c as l,bf as L,w as a,f as r,aq as u,bF as g,cD as y,cz as U,eM as I,eC as x,f5 as D,aC as V}from"./outputWidgets.f017b1ba.js";import{u as k}from"./index.7f38f098.js";import{a as E}from"./asyncComputed.9ec0ae7d.js";import{A as R,B as S,a as $,c as F}from"./index.0750564d.js";import{A as M}from"./Text.01ac3fdf.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[t]="5c5e1adc-ac3f-4637-8ea5-b1bb974faba1",s._sentryDebugIdIdentifier="sentry-dbid-5c5e1adc-ac3f-4637-8ea5-b1bb974faba1")}catch{}})();const P={class:"logo"},T=["src"],j=m({__name:"Logo",props:{brandName:{},logoUrl:{}},setup(s){const c=`${s.brandName} logo`;return(o,d)=>(n(),_("div",P,[o.logoUrl?(n(),_("img",{key:0,class:"logo-img",src:o.logoUrl,alt:c},null,8,T)):h("",!0),C("span",null,i(o.brandName),1)]))}});const q=N(j,[["__scopeId","data-v-b39249e9"]]),z=m({__name:"LoginBlock",setup(s){function t(b){const f=b.split("@")[0];return I.exports.kebabCase(f).toUpperCase().split("-").slice(0,2).map(p=>p[0]).join("")}const c=A(),{result:o,loading:d,refetch:v}=E(async()=>k.getUser());function w(){k.removeUser(),v(),c.push({name:"playerLogin"})}return(b,f)=>{const p=B("router-link");return e(d)?(n(),l(e(L),{key:0})):e(o)?(n(),l(e(U),{key:1,placement:"bottomRight"},{content:a(()=>[r(e(y),{direction:"vertical"},{default:a(()=>[r(e(M),null,{default:a(()=>[u(i(e(o).claims.email),1)]),_:1}),r(e(g),{onClick:w},{default:a(()=>[u("Logout")]),_:1})]),_:1})]),default:a(()=>[r(e(y),{align:"center",style:{cursor:"pointer"}},{default:a(()=>[r(e(R),null,{default:a(()=>[u(i(t(e(o).claims.email)),1)]),_:1})]),_:1})]),_:1})):(n(),l(e(g),{key:2},{default:a(()=>[r(p,{to:"/_player/login"},{default:a(()=>[u("Login")]),_:1})]),_:1}))}}}),Q=m({__name:"Navbar",props:{brandName:{},logoUrl:{},breadcrumb:{}},setup(s){return(t,c)=>(n(),l(e(F),{style:{padding:"5px 25px",width:"100vw"}},{breadcrumb:a(()=>[t.breadcrumb?(n(),l(e(S),{key:0},{default:a(()=>[(n(!0),_(V,null,x(t.breadcrumb,(o,d)=>(n(),l(e($),{key:d},{default:a(()=>[r(e(D),{to:o.path},{default:a(()=>[u(i(o.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):h("",!0)]),title:a(()=>[r(q,{"brand-name":t.brandName,"logo-url":t.logoUrl},null,8,["brand-name","logo-url"])]),extra:a(()=>[r(z)]),_:1}))}});export{Q as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.c7af449a.js.map
