import{v as t,b as s,eu as d}from"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="517059ae-00d4-4356-9166-71ddc7d4e571",e._sentryDebugIdIdentifier="sentry-dbid-517059ae-00d4-4356-9166-71ddc7d4e571")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),d("div",r,"Organization settings")}const f=t(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.9271f9e7.js.map
