import{f,eH as o,f8 as u}from"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="bdd48a3d-bdfd-4393-81f2-bb8ac1686c3f",e._sentryDebugIdIdentifier="sentry-dbid-bdd48a3d-bdfd-4393-81f2-bb8ac1686c3f")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(d){return Object.getOwnPropertyDescriptor(n,d).enumerable}))),r.forEach(function(d){c(e,d,n[d])})}return e}function c(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var a=function(t,n){var r=i({},t,n.attrs);return f(o,i({},r,{icon:u}),null)};a.displayName="LoadingOutlined";a.inheritAttrs=!1;const b=a;export{b as L};
//# sourceMappingURL=LoadingOutlined.00da78e9.js.map
