.choose-type[data-v-180fc155]{width:100%;height:100%;display:flex;justify-content:center;align-items:center;padding:40px 0}.option[data-v-180fc155]{width:120px;height:50px;border-radius:8px;display:flex;justify-content:center;align-items:center;border-width:1px;.option-content[data-v-180fc155] {display: flex; align-items: center; gap: 8px;}}.option[data-v-180fc155]:before{display:none}.scripts-container[data-v-8e101fc7]{padding-top:40px}.v-enter-active[data-v-8e101fc7],.v-leave-active[data-v-8e101fc7]{transition:all var(--956b41b2) ease}.v-enter-from[data-v-8e101fc7],.v-leave-to[data-v-8e101fc7]{transform:scale(0)}.ellipsis[data-v-8e101fc7]{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}
