import"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="4255030d-2268-45f8-9b6b-3cecd11fdf0b",e._sentryDebugIdIdentifier="sentry-dbid-4255030d-2268-45f8-9b6b-3cecd11fdf0b")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}},f=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([s,a])=>{t.searchParams.delete(s),n.set(s,a)}),`${t.origin}${t.pathname}?${n.toString()}`};export{d as i,f as m};
//# sourceMappingURL=url.42b30a4e.js.map
