import{D as f}from"./DeleteOutlined.f8ba9770.js";import{f as l,eH as u}from"./outputWidgets.f017b1ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="91d482ae-ef15-4ca6-8910-214d8c1d2319",e._sentryDebugIdIdentifier="sentry-dbid-91d482ae-ef15-4ca6-8910-214d8c1d2319")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){o(e,a,n[a])})}return e}function o(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var d=function(t,n){var r=i({},t,n.attrs);return l(u,i({},r,{icon:f}),null)};d.displayName="DeleteOutlined";d.inheritAttrs=!1;const b=d;export{b as D};
//# sourceMappingURL=DeleteOutlined.cea987e8.js.map
