import{_ as C}from"./logo.084e5d7c.js";import{v as I,b as r,eu as y,eF as w,eG as B,e as h,d as k,eA as L,a as D,u as e,c,bf as S,w as t,f as o,aq as l,eE as i,bF as m,cD as b,cz as N,eM as V,eC as E,f5 as F,aC as R,ew as M}from"./outputWidgets.f017b1ba.js";import{b as g}from"./router.bd5e0bcd.js";import{a as P}from"./asyncComputed.9ec0ae7d.js";import{A as T}from"./Text.01ac3fdf.js";import{A as $,B as j,a as q,c as z}from"./index.0750564d.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[s]="7b07efcf-a6d7-4250-accf-503d6619594a",a._sentryDebugIdIdentifier="sentry-dbid-7b07efcf-a6d7-4250-accf-503d6619594a")}catch{}})();const G={},v=a=>(w("data-v-439be421"),a=a(),B(),a),H={class:"logo"},U=v(()=>h("img",{class:"logo-img",src:C,alt:"Abstra cloud logo"},null,-1)),J=v(()=>h("span",null,"Abstra Cloud",-1)),K=[U,J];function O(a,s){return r(),y("div",H,K)}const Q=I(G,[["render",O],["__scopeId","data-v-439be421"]]),W=k({__name:"LoginBlock",setup(a){function s(p){const f=p.split("@")[0];return V.exports.kebabCase(f).toUpperCase().split("-").slice(0,2).map(_=>_[0]).join("")}const u=L(),{result:n,loading:d,refetch:A}=P(async()=>g.getAuthor());function x(){g.removeAuthor(),A(),u.push({name:"login"})}return(p,f)=>{const _=D("router-link");return e(d)?(r(),c(e(S),{key:0})):e(n)?(r(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(b),{direction:"vertical"},{default:t(()=>[o(e(T),null,{default:t(()=>[l(i(e(n).claims.email),1)]),_:1}),o(e(m),{onClick:x},{default:t(()=>[l("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(b),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e($),null,{default:t(()=>[l(i(s(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(m),{key:2},{default:t(()=>[o(_,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),oe=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(s,u)=>(r(),c(e(z),{style:{padding:"5px 25px"}},{breadcrumb:t(()=>[s.breadcrumb?(r(),c(e(j),{key:0},{default:t(()=>[(r(!0),y(R,null,E(s.breadcrumb,(n,d)=>(r(),c(e(q),{key:d},{default:t(()=>[o(e(F),{to:n.path},{default:t(()=>[l(i(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):M("",!0)]),title:t(()=>[o(Q)]),extra:t(()=>[o(W)]),_:1}))}});export{oe as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.e9e404c0.js.map
