:root{--main-font-family: DM Sans, sans-serif}:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel{background-color:#fff;padding:10px}.deploy-state-message{margin-bottom:8px}.action-buttons{justify-content:flex-end}.deploy-button{display:flex;gap:8px}[data-v-64ffaa47]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.linter-btn.info[data-v-64ffaa47]{color:#44a5ff;border-color:#44a5ff}.linter-btn.info[data-v-64ffaa47]:hover,.linter-btn.info[data-v-64ffaa47]:active{color:#44a5ff;border-color:#44a5ff;background-color:#e6f4ff}.linter-btn.warning[data-v-64ffaa47]{color:#ffc400;border-color:#ffc400}.linter-btn.warning[data-v-64ffaa47]:hover,.linter-btn.warning[data-v-64ffaa47]:active{color:#ffc400;border-color:#ffc400;background-color:#fffbe6}.linter-btn.error[data-v-64ffaa47]{color:#ff4f3e;border-color:#ff4f3e}.linter-btn.error[data-v-64ffaa47]:hover,.linter-btn.error[data-v-64ffaa47]:active{color:#ff4f3e;border-color:#ff4f3e;background-color:#d3524914}[data-v-2a8e46fc]:root{--main-font-family: DM Sans, sans-serif}[data-v-2a8e46fc]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-2a8e46fc]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-2a8e46fc]{background-color:#fff;padding:10px}
