import{u as s}from"./index.7f38f098.js";import{d,b as f,eu as l,f as n,u as r}from"./outputWidgets.f017b1ba.js";import{g as u}from"./api.646486da.js";import{K as b,L as c}from"./repository.469a5d35.js";import{_ as g}from"./Navbar.vue_vue_type_script_setup_true_lang.c7af449a.js";import{a as y}from"./asyncComputed.9ec0ae7d.js";import{P as _}from"./repository.875b9f0a.js";import"./pubsub.4d72db7b.js";import"./runnerData.69ad746c.js";import"./url.42b30a4e.js";import"./workspaces.aaea5068.js";import"./record.e2bcfa5f.js";import"./scripts.d8d6bdcc.js";import"./envVars.952414d1.js";import"./api.1f698687.js";import"./index.cf4c23b9.js";import"./PhScroll.vue.80bb185b.js";import"./PhWebhooksLogo.vue.bee1b0d9.js";import"./index.5cbbe314.js";import"./ant-design.f8dd6064.js";import"./index.11845c93.js";import"./Modal.334f8812.js";import"./Text.01ac3fdf.js";import"./Base.bb2b5283.js";import"./Typography.5dfc411f.js";import"./index.b5f796df.js";import"./Link.d1ea88f0.js";import"./Paragraph.3ffb559e.js";import"./Title.4002b692.js";import"./index.b5d890a4.js";import"./index.92e1480a.js";import"./index.97a56b04.js";import"./CollapsePanel.a2068d5c.js";import"./Timeline.f0acaa40.js";import"./index.0deb07e4.js";import"./index.76f119cc.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.4a8c0ef7.js";import"./Card.9bd70da8.js";import"./TabPane.3d7693e6.js";import"./hasIn.a2b4c2f9.js";import"./vuedraggable.umd.c790090d.js";import"./index.b2067256.js";import"./Form.c4ae4d63.js";import"./index.0750564d.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="a8e8eb37-5592-4f0f-986e-c47b8a55d25d",o._sentryDebugIdIdentifier="sentry-dbid-a8e8eb37-5592-4f0f-986e-c47b8a55d25d")}catch{}})();const bo=d({__name:"Kanban",setup(o){const t=new _(s),a=new c("kanban"),{result:e}=y(u);return(k,w)=>{var i,m,p;return f(),l("div",null,[n(g,{"brand-name":((i=r(e))==null?void 0:i.brandName)||((m=r(e))==null?void 0:m.name),"logo-url":(p=r(e))==null?void 0:p.logoUrl},null,8,["brand-name","logo-url"]),n(b,{"kanban-repository":r(t),storage:r(a)},null,8,["kanban-repository","storage"])])}}});export{bo as default};
//# sourceMappingURL=Kanban.65ec6645.js.map
