.data-container[data-v-541d30a8]{height:100px}.description[data-v-a8ca44f6]{margin-bottom:20px;font-style:italic;display:block}.form-preview-container[data-v-4b3585f2]{height:calc(100vh - 200px);min-height:500px;border-radius:10px;overflow:hidden;margin-top:20px}.url-preview[data-v-4b3585f2]{cursor:pointer}
